/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.perf;

import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

import javax.security.auth.login.LoginContext;
import javax.security.auth.login.LoginException;

import org.ow2.bonita.perf.approvalwf.ApprovalWorkflow;
import org.ow2.bonita.perf.habilitation.Habilitation;
import org.ow2.novabpm.perf.StressPerfTest;
import org.ow2.novabpm.util.SimpleCallbackHandler;

/**
 * @author Charles Souillard
 */
public final class StressTest {

  private StressTest() { }
  private static LoginContext loginContext;

  public static void main(String[] args) throws Exception {
    Map<String, String> aliasesMap = new TreeMap<String, String>();
    Map<String, String[]> globalAliasesMap = new HashMap<String, String[]>();

    aliasesMap.putAll(getLightAliasesMap());

    globalAliasesMap.putAll(getLightGlobalAliasesMap());
    //globalAliasesMap.put("all", (String[]) aliasesMap.keySet().toArray(new String[] {}));

    StressPerfTest test = new StressPerfTest(args, aliasesMap, globalAliasesMap);
    login();
    test.deployTests();
    test.launchTests();
    test.undeployTests();
    logout();
  }

  public static Map<String, String> getLightAliasesMap() {
    Map<String, String> aliasesMap = new TreeMap<String, String>();
    aliasesMap.put("light.approval", ApprovalWorkflow.class.getName());
    aliasesMap.put("light.habilitation", Habilitation.class.getName());
    return aliasesMap;
  }

  public static Map<String, String[]> getLightGlobalAliasesMap() {
    Map<String, String[]> globalAliasesMap = new HashMap<String, String[]>();
    globalAliasesMap.put("light.all", getLightAliasesMap().keySet().toArray(new String[] {}));
    return globalAliasesMap;
  }

  private static void login() throws LoginException {
    loginContext = new LoginContext("Bonita", new SimpleCallbackHandler("John", "bonita"));
    loginContext.login();
  }
  private static void logout() throws LoginException {
    loginContext.logout();
  }

}
